@@ -32,8 +32,8 @@ class DoublyLinkedList:
             self.head = node
         return node
 
-    def printlist(self):
-        temp=self.head
+    def printlist(self,h):
+        temp=h
         while temp!=None:
             print(temp.key," ",temp.val)
             temp=temp.next
