@@ -40,5 +40,8 @@ class FIFOCache:
                     self.list.deleteNode(self.list.tail)
                     self.map[key]=self.list.addToHead(key,value)
             self.verdata.set_data(key,value,self.list.head)
+    
+    def get_info(self):
+        return self.verdata.info()
 
 
